# WARNING: for packagers at each new zathura release all zathura-plugins
# (like djvu, ps and pdf-poppler) should absolutely be rebuilded otherwise
# zathura crashes, see mga#32937

Name:		zathura
Version:	0.5.11
Release:	%mkrel 2
Summary:	A lightweight document viewer
Group:		Publishing
License:	zlib
URL:		https://pwmt.org/projects/zathura/
Source0:	https://github.com/pwmt/zathura/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:	pkgconfig(check)
BuildRequires:	pkgconfig(girara-gtk3) >= 0.4.4
BuildRequires:	pkgconfig(libseccomp)
BuildRequires:	pkgconfig(sqlite3)
BuildRequires:	appstream-util
BuildRequires:	file-devel
BuildRequires:	meson
BuildRequires:	python3-sphinx
BuildRequires:	rsvg
BuildRequires:	x11-server-xvfb

# mga#32937
Recommends:	zathura-pdf-poppler
Suggests:	zathura-djvu
Suggests:	zathura-ps
Suggests:	zathura-cb

%description
Zathura is a highly customizable and functional document viewer.
It provides a minimalistic and space saving interface as well as
an easy usage that mainly focuses on keyboard interaction.

Zathura requires plugins to support document formats. For instance:
  * zathura-pdf-poppler to open PDF files,
  * zathura-ps to open PostScript files,
  * zathura-djvu to open DjVu files,
  * zathura-cb to open Comic book files.

All of these are available as separate packages.

A zathura-plugins meta-package is available if you want
to install all available plugins.

%package devel
Summary:	Development files for the zathura PDF viewer
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}

%description devel
This package contains the development files for the zathura PDF viewer.

%package plugins
Summary:	Meta-package for all Zathura plugins
Group:		Publishing
Requires:	zathura-cb
Requires:	zathura-djvu
Requires:	zathura-pdf-poppler
Requires:	zathura-ps

%description plugins
This package provides all Zathura plugins.

%prep
%autosetup -p1

%build
%meson \
	-Dsynctex=disabled
%meson_build

%install
%meson_install

#dir for plugins
mkdir -p %{buildroot}%{_libdir}/%{name}

%find_lang %{name}

%files -f %{name}.lang
%license LICENSE
%doc README*
%dir %{_libdir}/%{name}
%{_bindir}/%{name}
%{_bindir}/%{name}-sandbox
%{_mandir}/man*/*
%{_datadir}/applications/org.pwmt.zathura.desktop
%{_iconsdir}/hicolor/*/apps/org.pwmt.zathura.{png,svg}
%{_metainfodir}/org.pwmt.zathura.appdata.xml
%{_datadir}/dbus-1/interfaces/org.pwmt.zathura.xml
%{_datadir}/bash-completion/completions/zathura
%{_datadir}/zsh/site-functions/_zathura
%{_datadir}/fish/vendor_completions.d/zathura.fish

%files devel
%{_includedir}/zathura/
%{_libdir}/pkgconfig/zathura.pc

%files plugins


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 0.5.11-2.mga10
+ Revision: 2236080
- Mageia 10 Mass Rebuild

* Thu Feb 20 2025 daviddavid <daviddavid> 0.5.11-1.mga10
+ Revision: 2149924
- new version: 0.5.11

* Wed Aug 21 2024 daviddavid <daviddavid> 0.5.8-1.mga10
+ Revision: 2087307
- new version: 0.5.8

* Thu Mar 07 2024 daviddavid <daviddavid> 0.5.5-2.mga10
+ Revision: 2048253
- add also zathura-cb as available plugin in description
- add as suggested now available zathura-cb plugin

* Thu Mar 07 2024 daviddavid <daviddavid> 0.5.5-1.1.mga10
+ Revision: 2048078
- new version: 0.5.5

* Sun Dec 04 2022 wally <wally> 0.5.2-1.mga9
+ Revision: 1917488
- new version 0.5.2

* Tue Aug 09 2022 pol4n <pol4n> 0.4.9-1.mga9
+ Revision: 1876311
- new version 0.4.9

* Sat Apr 02 2022 umeabot <umeabot> 0.4.8-2.mga9
+ Revision: 1840776
- Mageia 9 Mass Rebuild

* Fri Nov 12 2021 wally <wally> 0.4.8-1.mga9
+ Revision: 1755939
- new version 0.4.8

* Sun Nov 08 2020 wally <wally> 0.4.7-1.mga8
+ Revision: 1643613
- new version 0.4.7

* Fri Apr 24 2020 wally <wally> 0.4.5-1.mga8
+ Revision: 1571709
- new version 0.4.5

* Sat Feb 15 2020 umeabot <umeabot> 0.4.3-3.mga8
+ Revision: 1525507
- Mageia 8 Mass Rebuild

* Thu Apr 18 2019 umeabot <umeabot> 0.4.3-2.mga7
+ Revision: 1392983
- Rebuild with meson 0.50.1

* Sun Mar 31 2019 wally <wally> 0.4.3-1.mga7
+ Revision: 1383394
- new version 0.4.3
- switch to meson build

* Sun Sep 23 2018 umeabot <umeabot> 0.3.7-2.mga7
+ Revision: 1302034
- Mageia 7 Mass Rebuild

* Tue Oct 10 2017 wally <wally> 0.3.7-1.mga7
+ Revision: 1170735
- new version 0.3.7

* Sat May 14 2016 wally <wally> 0.3.6-1.mga6
+ Revision: 1015438
- new version 0.3.6
- drop upstreamed 'build without synctex' patch

* Fri Jan 01 2016 wally <wally> 0.3.4-1.mga6
+ Revision: 917689
- new version 0.3.4
- add patch from Jan Palus to build without libsynctex

* Mon Jun 22 2015 wally <wally> 0.3.3-1.mga6
+ Revision: 839760
- new version 0.3.3

* Wed Oct 15 2014 umeabot <umeabot> 0.2.9-3.mga5
+ Revision: 745381
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.2.9-2.mga5
+ Revision: 690855
- Mageia 5 Mass Rebuild

* Thu Jun 26 2014 wally <wally> 0.2.9-1.mga5
+ Revision: 640118
- new version 0.2.9

* Tue Feb 18 2014 wally <wally> 0.2.7-1.mga5
+ Revision: 594461
- new version 0.2.7

* Tue Feb 04 2014 wally <wally> 0.2.6-1.mga5
+ Revision: 581076
- new version 0.2.6
- switch to gtk3

* Sat Oct 19 2013 umeabot <umeabot> 0.2.4-2.mga4
+ Revision: 532084
- Mageia 4 Mass Rebuild

* Thu Aug 15 2013 wally <wally> 0.2.4-1.mga4
+ Revision: 466758
- new version 0.2.4
- drop upstream applied patch

* Tue Jun 25 2013 wally <wally> 0.2.3-2.mga4
+ Revision: 446566
- enable meta pkg for all plugins
- edit description

* Mon Jun 24 2013 wally <wally> 0.2.3-1.mga4
+ Revision: 446317
- clean .spec
- imported package zathura


* Tue May 28 2013 François Cami <fcami@fedoraproject.org> - 0.2.3-6
- backport cdece5922982b06e1a86dfb7dfc8cf3d225f06f0

* Tue May 28 2013 François Cami <fcami@fedoraproject.org> - 0.2.3-5
- backport cf96d52790bc8d05a9e556e33af0b6fec1a4cb0e

* Tue May 28 2013 François Cami <fcami@fedoraproject.org> - 0.2.3-4
- rewrite summary.

* Mon May 27 2013 François Cami <fcami@fedoraproject.org> - 0.2.3-3
- add a zathura-plugins-all subpackage.

* Mon May 27 2013 François Cami <fcami@fedoraproject.org> - 0.2.3-2
- rewrite description.

* Tue May 21 2013 Petr Šabata <contyk@redhat.com> - 0.2.3-1
- 0.2.3 build
- Use more macros

* Sun May 12 2013 François Cami <fcami@fedoraproject.org> - 0.2.2-2
- add a note about plugins to avoid future occurrences of #962097

* Fri Feb 22 2013 Kevin Fenzi <kevin@scrye.com> 0.2.2-1
- Update to 0.2.2

* Thu Feb 14 2013 Michal Schmidt <mschmidt@redhat.com> 0.2.1-2
- fix building of manpages
- use parallel make

* Mon Nov 05 2012 Kevin Fenzi <kevin@scrye.com> 0.2.1-1
- Update to 0.2.1

* Sun Jul 22 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.8.5-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed May 16 2012 Marek Kasik <mkasik@redhat.com> - 0.0.8.5-4
- Rebuild (poppler-0.20.0)

* Sat Mar 31 2012 Peter Robinson <pbrobinson@fedoraproject.org> - 0.0.8.5-3
- Fix FTBFS on recent releases
- Update URLs
- Cleanup SPEC

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.8.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Tue Nov 15 2011 François Cami <fcami@fedoraproject.org> - 0.0.8.5-1
- Update to latest upstream.

* Fri Oct 28 2011 Rex Dieter <rdieter@fedoraproject.org> - 0.0.8.3-6
- rebuild(poppler)

* Fri Sep 30 2011 Marek Kasik <mkasik@redhat.com> - 0.0.8.3-5
- Rebuild (poppler-0.18.0)

* Mon Sep 19 2011 Marek Kasik <mkasik@redhat.com> - 0.0.8.3-4
- Rebuild (poppler-0.17.3)

* Fri Jul 15 2011 Marek Kasik <mkasik@redhat.com> - 0.0.8.3-3
- Rebuild (poppler-0.17.0)

* Sat Apr 02 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.0.8.3-2
- It's update-desktop-database, not update-mime-database

* Fri Apr 01 2011 Christoph Wickert <cwickert@fedoraproject.org> - 0.0.8.3-1
- Update to 0.0.8.3
- Drop patch for poppler >= 0.15 (no longer needed)
- Run update-mime-database in %%post and %%postun

* Sun Mar 13 2011 Marek Kasik <mkasik@redhat.com> - 0.0.8.2-5
- Rebuild (poppler-0.16.3)

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.0.8.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sat Jan 01 2011 Rex Dieter <rdieter@fedoraproject.org> - 0.0.8.2-3
- rebuild (poppler)

* Wed Dec 15 2010 Rex Dieter <rdieter@fedoraproject.org> - 0.0.8.2-2
- rebuild (poppler)

* Wed Dec 01 2010 François Cami <fcami@đedoraproject.ort> - 0.0.8.2-1
- new upstream version + drop merged patch (dso build fix)

* Sat Nov 06 2010 Rex Dieter <rdieter@fedoraproject.org> - 0.0.8.1-8
- rebuilt (poppler)

* Wed Oct  6 2010 Tom "spot" Callaway <tcallawa@redhat.com> - 0.0.8.1-7
- rebuild and fix for new poppler

* Fri Aug 20 2010 Rex Dieter <rdieter@fedoraproject.org> - 0.0.8.1-6
- rebuild (poppler)

* Sun Aug 15 2010 François Cami <fcami@fedoraproject.org> 0.0.8.1-5
- switch to sed (Kevin Fenzi).
- use desktop-file-validate on the desktop file (Kevin Fenzi).

* Sun Aug 15 2010 François Cami <fcami@fedoraproject.org> 0.0.8.1-4
- change zathura.desktop Version to 1.0.

* Sat Aug 14 2010 François Cami <fcami@fedoraproject.org> 0.0.8.1-3
- add CFLAGS (Kevin Fenzi).
- use the debug target to generate the debuginfo rpm properly.
- add zathura.desktop file and install it.

* Sat Aug 14 2010 François Cami <fcami@fedoraproject.org> 0.0.8.1-2
- fix licensing, thanks to Dennis Johnson's review.

* Tue Aug 10 2010 François Cami <fcami@fedoraproject.org> 0.0.8.1-1
- initial package.

